@@ -38,8 +38,7 @@ except ImportError:
 from threading import Lock
 import dateutil.tz
 
-from tryton.exceptions import (TrytonServerError, TrytonError,
-    TrytonServerUnavailable)
+from tryton.exceptions import TrytonServerError, TrytonError
 from tryton.pyson import PYSONEncoder
 
 _ = gettext.gettext
@@ -997,20 +996,7 @@ def process_exception(exception, *args, **kwargs):
 
     rpc_execute = kwargs.get('rpc_execute', rpc.execute)
 
-    if isinstance(exception, TrytonError):
-        if exception.faultCode == 'BadFingerprint':
-            warning(
-                _('The server fingerprint has changed since last connection.\n'
-                'The application will stop connecting to this server '
-                'until its fingerprint is fixed.'), _('Security risk.'))
-            from tryton.gui.main import Main
-            Main.sig_quit()
-        elif exception.faultCode.startswith('403'):
-            if rpc.CONNECTION is None:
-                message(_('Connection error.\n'
-                        'Unable to connect to the server.'))
-                return False
-    elif isinstance(exception, TrytonServerError):
+    if isinstance(exception, TrytonServerError):
         if exception.faultCode == 'UserWarning':
             name, msg, description = exception.args
             res = userwarning(description, msg)
@@ -1030,12 +1016,9 @@ def process_exception(exception, *args, **kwargs):
                     except TrytonServerError, exception:
                         return process_exception(exception, *args,
                             rpc_execute=rpc_execute)
-                return True
-            return False
         elif exception.faultCode == 'UserError':
             msg, description = exception.args
             warning(description, msg)
-            return False
         elif exception.faultCode == 'ConcurrencyException':
             if len(args) >= 6:
                 if concurrency(args[1], args[3][0], args[5]):
@@ -1046,14 +1029,13 @@ def process_exception(exception, *args, **kwargs):
                     except TrytonServerError, exception:
                         return process_exception(exception, *args,
                             rpc_execute=rpc_execute)
-                return False
             else:
                 message(_('Concurrency Exception'), msg_type=gtk.MESSAGE_ERROR)
-                return False
-        elif exception.faultCode.startswith('403'):
+        elif (exception.faultCode.startswith('403')
+                or exception.faultCode.startswith('401')):
             from tryton.gui.main import Main
             if not PLOCK.acquire(False):
-                return False
+                return
             language = CONFIG['client.lang']
             func = lambda parameters: rpc.login(
                 rpc._HOST, rpc._PORT, rpc._DATABASE, rpc._USERNAME, parameters,
@@ -1072,17 +1054,11 @@ def process_exception(exception, *args, **kwargs):
                 except TrytonServerError, exception:
                     return process_exception(exception, *args,
                         rpc_execute=rpc_execute)
-    elif isinstance(exception, (socket.error, TrytonServerUnavailable)):
-        warning(str(exception), _('Network Error.'))
-        return False
-
-    if isinstance(exception, TrytonServerError):
-        error_title, error_detail = exception.faultCode, exception.faultString
+        else:
+            error(exception.faultCode, exception.faultString)
     else:
-        error_title = str(exception)
-        error_detail = traceback.format_exc()
-    error(error_title, error_detail)
-    return False
+        error(str(exception), traceback.format_exc())
+    raise RPCException(exception)
 
 
 class Login(object):
@@ -1215,22 +1191,15 @@ class RPCProgress(object):
     def process(self):
         if self.parent and self.parent.get_window():
             self.parent.get_window().set_cursor(None)
-        if self.exception:
-            if self.process_exception_p:
-                def rpc_execute(*args):
-                    return RPCProgress('execute',
-                        args).run(self.process_exception_p)
-                result = process_exception(self.exception, *self.args,
-                    rpc_execute=rpc_execute)
-                if result is False:
-                    self.exception = RPCException(self.exception)
-                else:
-                    self.exception = None
-                    self.res = result
 
         def return_():
             if self.exception:
-                raise self.exception
+                if self.process_exception_p:
+                    def rpc_execute(*args):
+                        return RPCProgress('execute',
+                            args).run(self.process_exception_p, self.callback)
+                    return process_exception(self.exception, *self.args,
+                        rpc_execute=rpc_execute)
             else:
                 return self.res
 
@@ -1397,7 +1366,6 @@ def get_label_attributes(readonly, required):
             weight = pango.WEIGHT_NORMAL
     attrlist = pango.AttrList()
     if hasattr(pango, 'AttrWeight'):
-        # FIXME when Pango.attr_weight_new is introspectable
         attrlist.change(pango.AttrWeight(weight, 0, -1))
     if hasattr(pango, 'AttrStyle'):
         attrlist.change(pango.AttrStyle(style, 0, -1))
